Entropic's Documentation
====================================
Entropic is a data pipeline framework designed to provide scientists with a simple and efficient way to access data from their experiments.

Install it using pip::

   pip install entropic

Entropic needs Python 3.9+, and relies mostly on:

* `Pydantic <https://docs.pydantic.dev/latest/>`_ for data validation.
* `Pandas <https://pandas.pydata.org/>`_ for data analysis.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Examples
   Reference/index
   Tutorial/index

